@@ -25,6 +25,8 @@
 #include <libgda/gda-row.h>
 
 struct _GdaRow {
+	GdaDataModel *model;
+	gint number;
 	gchar *id;
 	GdaValue *fields;
 	gint nfields;
@@ -32,6 +34,7 @@ struct _GdaRow {
 
 /**
  * gda_row_new
+ * model: the #GdaDataModel this row belongs to.
  * @count: number of #GdaValue in the new #GdaRow.
  *
  * Creates a #GdaRow which can hold @count #GdaValue.
@@ -39,13 +42,15 @@ struct _GdaRow {
  * Returns: the newly allocated #GdaRow.
  */
 GdaRow *
-gda_row_new (gint count)
+gda_row_new (GdaDataModel *model, gint count)
 {
 	GdaRow *row = NULL;
 
 	g_return_val_if_fail (count >= 0, NULL);
 
 	row = g_new0 (GdaRow, 1);
+	row->model = model;
+	row->number = -1;
 	row->id = NULL;
 	row->nfields = count;
 	row->fields = g_new0 (GdaValue, count);
@@ -62,13 +67,13 @@ gda_row_new (gint count)
  * Returns: the newly created row.
  */
 GdaRow *
-gda_row_new_from_list (const GList *values)
+gda_row_new_from_list (GdaDataModel *model, const GList *values)
 {
 	GdaRow *row;
 	const GList *l;
 	gint i;
 
-	row = gda_row_new (g_list_length ((GList *) values));
+	row = gda_row_new (model, g_list_length ((GList *) values));
 	for (i = 0, l = values; l != NULL; l = l->next, i++) {
 		const GdaValue *value = (const GdaValue *) l->data;
 
@@ -101,6 +106,51 @@ gda_row_free (GdaRow *row)
 	g_free (row);
 }
 
+/**
+ * gda_row_get_model
+ * @row: a #GdaRow.
+ *
+ * Get the #GdaDataModel the given #GdaRow belongs to.
+ *
+ * Returns: a #GdaDataModel.
+ */
+GdaDataModel *
+gda_row_get_model (GdaRow *row)
+{
+	g_return_val_if_fail (row != NULL, NULL);
+	return row->model;
+}
+
+/**
+ * gda_row_get_number
+ * @row: a #GdaRow.
+ *
+ * Get the number of the given row, that is, its position in its containing
+ * data model.
+ *
+ * Returns: the row number, or -1 if there was an error.
+ */
+gint
+gda_row_get_number (GdaRow *row)
+{
+	g_return_val_if_fail (row != NULL, -1);
+	return row->number;
+}
+
+/**
+ * gda_row_set_number
+ * @row: a #GdaRow.
+ * @number: the new row number.
+ *
+ * Set the row number for the given row.
+ */
+void
+gda_row_set_number (GdaRow *row, gint number)
+{
+	g_return_if_fail (row != NULL);
+	row->number = 0;
+}
+
 /**
  * gda_row_get_id
  * @row: a #GdaRow (which contains #GdaValue).
@@ -145,10 +195,13 @@ gda_row_set_id (GdaRow *row, const gchar *id)
  * @num: field index.
  *
  * Gets a pointer to a #GdaValue stored in a #GdaRow.
+ *
+ * This is a pointer to the internal array of values. Don't try to free
+ * or modify it!
  * 
  * Returns: a pointer to the #GdaValue in the position @num of @row.
  */
-GdaValue *
+G_CONST_RETURN GdaValue *
 gda_row_get_value (GdaRow *row, gint num)
 {
 	g_return_val_if_fail (row != NULL, NULL);
