@@ -127,6 +127,7 @@ set_from_string (GdaValue *value, const gchar *as_string)
 	gchar *endptr [1];
 	gdouble dvalue;
 	glong lvalue;
+        gulong ulvalue;
 
 	g_return_val_if_fail (value != NULL, FALSE);
 
@@ -153,6 +154,13 @@ set_from_string (GdaValue *value, const gchar *as_string)
 			retval = TRUE;
 		}
 		break;
+        case GDA_VALUE_TYPE_BIGUINT :
+ 	        dvalue = g_strtod (as_string, endptr);
+                if (*as_string!=0 && **endptr==0) {
+                  gda_value_set_biguint(value,(guint64)dvalue);
+                  retval=TRUE;
+                }
+                break;
 	case GDA_VALUE_TYPE_INTEGER :
 		lvalue = strtol (as_string, endptr, 10);
 		if (*as_string != '\0' && **endptr == '\0'){
@@ -160,6 +168,13 @@ set_from_string (GdaValue *value, const gchar *as_string)
 			retval = TRUE;
 		}
 		break;
+        case GDA_VALUE_TYPE_UINTEGER :
+                ulvalue = strtoul (as_string, endptr, 10);
+                if (*as_string!=0 && **endptr==0) {
+                  gda_value_set_uinteger(value,(guint32)ulvalue);
+                  retval=TRUE;
+                }
+                break;
 	case GDA_VALUE_TYPE_SMALLINT :
 		lvalue = strtol (as_string, endptr, 10);
 		if (*as_string != '\0' && **endptr == '\0'){
@@ -167,6 +182,27 @@ set_from_string (GdaValue *value, const gchar *as_string)
 			retval = TRUE;
 		}
 		break;
+        case GDA_VALUE_TYPE_SMALLUINT :
+                ulvalue = strtoul (as_string, endptr, 10);
+                if (*as_string!=0 && **endptr==0) {
+                  gda_value_set_smalluint(value,(guint16)ulvalue);
+                  retval=TRUE;
+                }
+                break;
+        case GDA_VALUE_TYPE_TINYINT :
+                lvalue = strtol(as_string, endptr, 10);
+                if (*as_string!=0 && **endptr==0) {
+                  gda_value_set_tinyint(value,(gchar)lvalue);
+                  retval=TRUE;
+                }
+                break;
+        case GDA_VALUE_TYPE_TINYUINT :
+                ulvalue = strtoul(as_string,endptr, 10);
+                if (*as_string!=0 && **endptr==0) {
+                  gda_value_set_tinyuint(value,(guchar)ulvalue);
+                  retval=TRUE;
+                }
+                break;
 	case GDA_VALUE_TYPE_SINGLE :
 		dvalue = g_strtod (as_string, endptr);
 		if (*as_string != '\0' && **endptr == '\0'){
@@ -277,6 +313,23 @@ gda_value_new_bigint (gint64 val)
 	return value;
 }
 
+/**
+ * gda_value_new_biguint
+ * @val: value to set for the new #GdaValue.
+ *
+ * Make a new #GdaValue of type #GDA_VALUE_TYPE_BIGUINT with value @val.
+ *
+ * Returns: The newly created #GdaValue.
+ */
+
+GdaValue *gda_value_new_biguint(guint64 val) {
+  GdaValue *value;
+
+  value = g_new0(GdaValue,1);
+  gda_value_set_biguint(value,val);
+  return value;
+}
+
 /**
  * gda_value_new_binary
  * @val: value to set for the new #GdaValue.
@@ -411,6 +464,24 @@ gda_value_new_integer (gint val)
 	return value;
 }
 
+/**
+ * gda_value_new_uinteger
+ * @val: value to set for the new #GdaValue.
+ *
+ * Make a new #GdaValue of type #GDA_VALUE_TYPE_UINTEGER with value @val.
+ *
+ * Returns: The newly created #GdaValue.
+ */
+
+GdaValue *gda_value_new_uinteger(guint val) {
+  GdaValue *value;
+
+  value=g_new0(GdaValue,1);
+  gda_value_set_uinteger(value,val);
+  return value;
+}
+
+
 /**
  * gda_value_new_list
  * @val: value to set for the new #GdaValue.
@@ -506,6 +577,25 @@ gda_value_new_smallint (gshort val)
 	return value;
 }
 
+/**
+ * gda_value_new_smalluint
+ * @val: value to set for the new #GdaValue.
+ *
+ * Make a new #GdaValue of type #GDA_VALUE_TYPE_SMALLUINT with value @val.
+ *
+ * Returns: The newly created #GdaValue.
+ */
+GdaValue *
+gda_value_new_smalluint (gushort val)
+{
+	GdaValue *value;
+
+	value = g_new0 (GdaValue, 1);
+	gda_value_set_smalluint (value, val);
+
+	return value;
+}
+
 /**
  * gda_value_new_string
  * @val: value to set for the new #GdaValue.
@@ -615,6 +705,25 @@ gda_value_new_tinyint (gchar val)
 	return value;
 }
 
+/**
+ * gda_value_new_tinyuint
+ * @val: value to set for the new #GdaValue.
+ *
+ * Make a new #GdaValue of type #GDA_VALUE_TYPE_TINYUINT with value @val.
+ *
+ * Returns: The newly created #GdaValue.
+ */
+GdaValue *
+gda_value_new_tinyuint (guchar val)
+{
+	GdaValue *value;
+
+	value = g_new0 (GdaValue, 1);
+	gda_value_set_tinyuint (value, val);
+
+	return value;
+}
+
 /**
  * gda_value_new_type
  * @val: Value to set for the new #GdaValue.
@@ -716,7 +825,7 @@ gda_value_free (GdaValue *value)
  * Returns: the #GdaValueType of the value.
  */
 GdaValueType
-gda_value_get_type (GdaValue *value)
+gda_value_get_type (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, GDA_VALUE_TYPE_UNKNOWN);
 	return value->type;
@@ -732,7 +841,7 @@ gda_value_get_type (GdaValue *value)
  * #GDA_VALUE_TYPE_NULL.
  */
 gboolean
-gda_value_is_null (GdaValue *value)
+gda_value_is_null (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, FALSE);
 	return value->type == GDA_VALUE_TYPE_NULL;
@@ -748,7 +857,7 @@ gda_value_is_null (GdaValue *value)
  * Returns: TRUE if a number, FALSE otherwise.
  */
 gboolean
-gda_value_is_number (GdaValue *value)
+gda_value_is_number (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, FALSE);
 
@@ -761,8 +870,12 @@ gda_value_is_number (GdaValue *value)
 	case GDA_VALUE_TYPE_SINGLE :
 	case GDA_VALUE_TYPE_SMALLINT :
 	case GDA_VALUE_TYPE_TINYINT :
+        case GDA_VALUE_TYPE_BIGUINT :
+        case GDA_VALUE_TYPE_UINTEGER :
+        case GDA_VALUE_TYPE_SMALLUINT :
+        case GDA_VALUE_TYPE_TINYUINT :
 		return TRUE;
-	default :
+	default :;
 	}
 
 	return FALSE;
@@ -791,6 +904,9 @@ gda_value_copy (const GdaValue *value)
 	case GDA_VALUE_TYPE_BIGINT :
 		copy->value.v_bigint = value->value.v_bigint;
 		break;
+        case GDA_VALUE_TYPE_BIGUINT :
+                copy->value.v_biguint = value->value.v_biguint;
+                break;
 	case GDA_VALUE_TYPE_BINARY :
 		copy->value.v_binary = g_malloc0 (value->binary_length);
 		copy->binary_length = value->binary_length;
@@ -815,6 +931,9 @@ gda_value_copy (const GdaValue *value)
 	case GDA_VALUE_TYPE_INTEGER :
 		copy->value.v_integer = value->value.v_integer;
 		break;
+        case GDA_VALUE_TYPE_UINTEGER :
+                copy->value.v_uinteger = value->value.v_uinteger;
+                break;
 	case GDA_VALUE_TYPE_LIST :
 		copy->value.v_list = NULL;
 		for (l = value->value.v_list; l != NULL; l = l->next) {
@@ -836,6 +955,9 @@ gda_value_copy (const GdaValue *value)
 	case GDA_VALUE_TYPE_SMALLINT :
 		copy->value.v_smallint = value->value.v_smallint;
 		break;
+        case GDA_VALUE_TYPE_SMALLUINT :
+                copy->value.v_smalluint = value->value.v_smalluint;
+                break;
 	case GDA_VALUE_TYPE_STRING :
 		copy->value.v_string = g_strdup (value->value.v_string);
 		break;
@@ -848,6 +970,9 @@ gda_value_copy (const GdaValue *value)
 	case GDA_VALUE_TYPE_TINYINT :
 		copy->value.v_tinyint = value->value.v_tinyint;
 		break;
+        case GDA_VALUE_TYPE_TINYUINT :
+                copy->value.v_tinyuint = value->value.v_tinyuint;
+                break;
 	case GDA_VALUE_TYPE_TYPE :
 		copy->value.v_type = value->value.v_type;
 		break;
@@ -869,7 +994,7 @@ gda_value_copy (const GdaValue *value)
  * Returns: the value contained in @value.
  */
 gint64
-gda_value_get_bigint (GdaValue *value)
+gda_value_get_bigint (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_BIGINT), -1);
@@ -893,6 +1018,39 @@ gda_value_set_bigint (GdaValue *value, gint64 val)
 	value->value.v_bigint = val;
 }
 
+/**
+ * gda_value_get_biguint
+ * @value: a #GdaValue whose value we want to get.
+ *
+ * Gets the value stored in @value.
+ * 
+ * Returns: the value contained in @value.
+ */
+guint64
+gda_value_get_biguint (const GdaValue *value)
+{
+	g_return_val_if_fail (value != NULL, -1);
+	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_BIGUINT), -1);
+	return value->value.v_biguint;
+}
+
+/**
+ * gda_value_set_biguint
+ * @value: a #GdaValue that will store @val.
+ * @val: value to be stored in @value.
+ *
+ * Stores @val into @value.
+ */
+void
+gda_value_set_biguint (GdaValue *value, guint64 val)
+{
+	g_return_if_fail (value != NULL);
+
+	clear_value (value);
+	value->type = GDA_VALUE_TYPE_BIGUINT;
+	value->value.v_biguint = val;
+}
+
 /**
  * gda_value_get_binary
  * @value: a #GdaValue whose value we want to get.
@@ -902,10 +1060,10 @@ gda_value_set_bigint (GdaValue *value, gint64 val)
  * 
  * Returns: the value contained in @value.
  */
-gconstpointer
-gda_value_get_binary (GdaValue *value, glong *size)
+G_CONST_RETURN gpointer
+gda_value_get_binary (const GdaValue *value, glong *size)
 {
-	gconstpointer val;
+	gpointer val;
 
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_BINARY), NULL);
@@ -946,7 +1104,7 @@ gda_value_set_binary (GdaValue *value, gconstpointer val, glong size)
  * Returns: the value contained in @value.
  */
 gboolean
-gda_value_get_boolean (GdaValue *value)
+gda_value_get_boolean (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, FALSE);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_BOOLEAN), FALSE);
@@ -978,8 +1136,8 @@ gda_value_set_boolean (GdaValue *value, gboolean val)
  * 
  * Returns: the value contained in @value.
  */
-const GdaDate *
-gda_value_get_date (GdaValue *value)
+G_CONST_RETURN GdaDate *
+gda_value_get_date (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_DATE), NULL);
@@ -1015,7 +1173,7 @@ gda_value_set_date (GdaValue *value, const GdaDate *val)
  * Returns: the value contained in @value.
  */
 gdouble
-gda_value_get_double (GdaValue *value)
+gda_value_get_double (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_DOUBLE), -1);
@@ -1047,8 +1205,8 @@ gda_value_set_double (GdaValue *value, gdouble val)
  * 
  * Returns: the value contained in @value.
  */
-const GdaGeometricPoint *
-gda_value_get_geometric_point (GdaValue *value)
+G_CONST_RETURN GdaGeometricPoint *
+gda_value_get_geometric_point (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_GEOMETRIC_POINT), NULL);
@@ -1080,8 +1238,8 @@ gda_value_set_geometric_point (GdaValue *value, const GdaGeometricPoint *val)
  *
  * Gets the value stored in @value.
  */
-const GObject *
-gda_value_get_gobject (GdaValue *value)
+G_CONST_RETURN GObject *
+gda_value_get_gobject (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_GOBJECT), NULL);
@@ -1116,7 +1274,7 @@ gda_value_set_gobject (GdaValue *value, const GObject *val)
  * Returns: the value contained in @value.
  */
 gint
-gda_value_get_integer (GdaValue *value)
+gda_value_get_integer (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_INTEGER), -1);
@@ -1148,8 +1306,8 @@ gda_value_set_integer (GdaValue *value, gint val)
  * 
  * Returns: the value contained in @value.
  */
-const GdaValueList *
-gda_value_get_list (GdaValue *value)
+G_CONST_RETURN GdaValueList *
+gda_value_get_list (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_LIST), NULL);
@@ -1180,8 +1338,8 @@ gda_value_set_list (GdaValue *value, const GdaValueList *val)
  * 
  * Returns: the value contained in @value.
  */
-const GdaMoney *
-gda_value_get_money (GdaValue *value)
+G_CONST_RETURN GdaMoney *
+gda_value_get_money (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_MONEY), NULL);
@@ -1230,8 +1388,8 @@ gda_value_set_null (GdaValue *value)
  * 
  * Returns: the value contained in @value.
  */
-const GdaNumeric *
-gda_value_get_numeric (GdaValue *value)
+G_CONST_RETURN GdaNumeric *
+gda_value_get_numeric (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_NUMERIC), NULL);
@@ -1267,7 +1425,7 @@ gda_value_set_numeric (GdaValue *value, const GdaNumeric *val)
  * Returns: the value contained in @value.
  */
 gfloat
-gda_value_get_single (GdaValue *value)
+gda_value_get_single (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_SINGLE), -1);
@@ -1300,7 +1458,7 @@ gda_value_set_single (GdaValue *value, gfloat val)
  * Returns: the value contained in @value.
  */
 gshort
-gda_value_get_smallint (GdaValue *value)
+gda_value_get_smallint (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_SMALLINT), -1);
@@ -1324,6 +1482,39 @@ gda_value_set_smallint (GdaValue *value, gshort val)
 	value->value.v_smallint = val;
 }
 
+/**
+ * gda_value_get_smalluint
+ * @value: a #GdaValue whose value we want to get.
+ *
+ * Gets the value stored in @value.
+ * 
+ * Returns: the value contained in @value.
+ */
+gushort
+gda_value_get_smalluint (const GdaValue *value)
+{
+	g_return_val_if_fail (value != NULL, -1);
+	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_SMALLUINT), -1);
+	return value->value.v_smalluint;
+}
+
+/**
+ * gda_value_set_smalluint
+ * @value: a #GdaValue that will store @val.
+ * @val: value to be stored in @value.
+ *
+ * Stores @val into @value.
+ */
+void
+gda_value_set_smalluint (GdaValue *value, gushort val)
+{
+	g_return_if_fail (value != NULL);
+
+	clear_value (value);
+	value->type = GDA_VALUE_TYPE_SMALLUINT;
+	value->value.v_smalluint = val;
+}
+
 /**
  * gda_value_get_string
  * @value: a #GdaValue whose value we want to get.
@@ -1333,7 +1524,7 @@ gda_value_set_smallint (GdaValue *value, gshort val)
  * Returns: the value contained in @value.
  */
 const gchar *
-gda_value_get_string (GdaValue *value)
+gda_value_get_string (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_STRING), NULL);
@@ -1366,7 +1557,7 @@ gda_value_set_string (GdaValue *value, const gchar *val)
  * Returns: the value contained in @value.
  */
 const GdaTime *
-gda_value_get_time (GdaValue *value)
+gda_value_get_time (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_TIME), NULL);
@@ -1403,7 +1594,7 @@ gda_value_set_time (GdaValue *value, const GdaTime *val)
  * Returns: the value contained in @value.
  */
 const GdaTimestamp *
-gda_value_get_timestamp (GdaValue *value)
+gda_value_get_timestamp (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_TIMESTAMP), NULL);
@@ -1444,7 +1635,7 @@ gda_value_set_timestamp (GdaValue *value, const GdaTimestamp *val)
  * Returns: the value contained in @value.
  */
 gchar
-gda_value_get_tinyint (GdaValue *value)
+gda_value_get_tinyint (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, -1);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_TINYINT), -1);
@@ -1468,6 +1659,72 @@ gda_value_set_tinyint (GdaValue *value, gchar val)
 	value->value.v_tinyint = val;
 }
 
+/**
+ * gda_value_get_tinyuint
+ * @value: a #GdaValue whose value we want to get.
+ *
+ * Gets the value stored in @value.
+ * 
+ * Returns: the value contained in @value.
+ */
+guchar
+gda_value_get_tinyuint (const GdaValue *value)
+{
+	g_return_val_if_fail (value != NULL, -1);
+	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_TINYUINT), -1);
+	return value->value.v_tinyuint;
+}
+
+/**
+ * gda_value_set_tinyuint
+ * @value: a #GdaValue that will store @val.
+ * @val: value to be stored in @value.
+ *
+ * Stores @val into @value.
+ */
+void
+gda_value_set_tinyuint (GdaValue *value, guchar val)
+{
+	g_return_if_fail (value != NULL);
+
+	clear_value (value);
+	value->type = GDA_VALUE_TYPE_TINYUINT;
+	value->value.v_tinyuint = val;
+}
+
+/**
+ * gda_value_get_uinteger
+ * @value: a #GdaValue whose value we want to get.
+ *
+ * Gets the value stored in @value.
+ * 
+ * Returns: the value contained in @value.
+ */
+guint
+gda_value_get_uinteger (const GdaValue *value)
+{
+	g_return_val_if_fail (value != NULL, -1);
+	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_UINTEGER), -1);
+	return value->value.v_uinteger;
+}
+
+/**
+ * gda_value_set_uinteger
+ * @value: a #GdaValue that will store @val.
+ * @val: value to be stored in @value.
+ *
+ * Stores @val into @value.
+ */
+void
+gda_value_set_uinteger (GdaValue *value, guint val)
+{
+	g_return_if_fail (value != NULL);
+
+	clear_value (value);
+	value->type = GDA_VALUE_TYPE_UINTEGER;
+	value->value.v_uinteger = val;
+}
+
 /**
  * gda_value_get_vtype
  * @value: a #GdaValue whose value we want to get.
@@ -1477,7 +1734,7 @@ gda_value_set_tinyint (GdaValue *value, gchar val)
  * Returns: the value contained in @value.
  **/
 GdaValueType
-gda_value_get_vtype (GdaValue *value)
+gda_value_get_vtype (const GdaValue *value)
 {
 	g_return_val_if_fail (value != NULL, GDA_VALUE_TYPE_UNKNOWN);
 	g_return_val_if_fail (gda_value_isa (value, GDA_VALUE_TYPE_TYPE), GDA_VALUE_TYPE_UNKNOWN);
@@ -1551,6 +1808,9 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
 	case GDA_VALUE_TYPE_BIGINT :
 		gda_value_set_bigint (value, gda_value_get_bigint ((GdaValue *) from));
 		break;
+        case GDA_VALUE_TYPE_BIGUINT :
+                gda_value_set_biguint (value, gda_value_get_biguint ((GdaValue*) from));
+                break;
 	case GDA_VALUE_TYPE_BINARY :
 		gda_value_set_binary (value, from->value.v_binary, from->binary_length);
 		break;
@@ -1572,6 +1832,9 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
 	case GDA_VALUE_TYPE_INTEGER :
 		gda_value_set_integer (value, gda_value_get_integer ((GdaValue *) from));
 		break;
+        case GDA_VALUE_TYPE_UINTEGER :
+                gda_value_set_uinteger (value, gda_value_get_integer ((GdaValue *)from));
+                break;
 	case GDA_VALUE_TYPE_LIST :
 		gda_value_set_list (value, gda_value_get_list ((GdaValue *) from));
 		break;
@@ -1585,8 +1848,11 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
 		gda_value_set_single (value, gda_value_get_single ((GdaValue *) from));
 		break;
 	case GDA_VALUE_TYPE_SMALLINT :
-		gda_value_set_smallint (value, gda_value_get_smallint ((GdaValue *) from));
+		gda_value_set_smallint (value,gda_value_get_smallint ((GdaValue *) from));
 		break;
+        case GDA_VALUE_TYPE_SMALLUINT :
+                gda_value_set_smalluint(value,gda_value_get_smalluint((GdaValue*)from));
+                break;
 	case GDA_VALUE_TYPE_STRING :
 		gda_value_set_string (value, gda_value_get_string ((GdaValue *) from));
 		break;
@@ -1599,6 +1865,9 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
 	case GDA_VALUE_TYPE_TINYINT :
 		gda_value_set_tinyint (value, gda_value_get_tinyint ((GdaValue *) from));
 		break;
+        case GDA_VALUE_TYPE_TINYUINT :
+                gda_value_set_tinyuint(value, gda_value_get_tinyuint((GdaValue*)from));
+                break;
 	case GDA_VALUE_TYPE_TYPE :
 		clear_value (value);
 		value->type = GDA_VALUE_TYPE_TYPE;
@@ -1622,7 +1891,7 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
  * the preceding table.
  */
 gchar *
-gda_value_stringify (GdaValue *value)
+gda_value_stringify (const GdaValue *value)
 {
 	const GdaTime *gdatime;
 	const GdaDate *gdadate;
@@ -1640,6 +1909,9 @@ gda_value_stringify (GdaValue *value)
 	case GDA_VALUE_TYPE_BIGINT:
 		retval = g_strdup_printf ("%lld", gda_value_get_bigint (value));
 		break;
+        case GDA_VALUE_TYPE_BIGUINT:
+                retval = g_strdup_printf ("%llu", gda_value_get_biguint (value));
+                break;
 	case GDA_VALUE_TYPE_BINARY :
 		retval = g_malloc0 (value->binary_length + 1);
 		memcpy (retval, value->value.v_binary, value->binary_length);
@@ -1657,12 +1929,21 @@ gda_value_stringify (GdaValue *value)
 	case GDA_VALUE_TYPE_INTEGER:
 		retval = g_strdup_printf ("%d", gda_value_get_integer (value));
 		break;
+        case GDA_VALUE_TYPE_UINTEGER:
+                retval = g_strdup_printf ("%u", gda_value_get_uinteger (value));
+                break;
 	case GDA_VALUE_TYPE_SMALLINT:
 		retval = g_strdup_printf ("%d", gda_value_get_smallint (value));
 		break;
+        case GDA_VALUE_TYPE_SMALLUINT:
+                retval = g_strdup_printf ("%u", gda_value_get_smalluint (value));
+                break;
 	case GDA_VALUE_TYPE_TINYINT:
 		retval = g_strdup_printf ("%d", gda_value_get_tinyint (value));
 		break;
+        case GDA_VALUE_TYPE_TINYUINT:
+                retval = g_strdup_printf ("%u", gda_value_get_tinyuint (value));
+                break;
 	case GDA_VALUE_TYPE_SINGLE:
 		retval = g_strdup_printf ("%.2f", gda_value_get_single (value));
 		break;
@@ -1676,7 +1957,7 @@ gda_value_stringify (GdaValue *value)
 					  gdatime->hour,
 					  gdatime->minute,
 					  gdatime->second,
-					  gdatime->timezone / 3600);
+					  (int) gdatime->timezone / 3600);
 		break;
 	case GDA_VALUE_TYPE_DATE:
 		gdadate = gda_value_get_date (value);
@@ -1696,8 +1977,8 @@ gda_value_stringify (GdaValue *value)
 					  timestamp->hour,
 					  timestamp->minute,
 					  timestamp->second,
-					  timestamp->fraction,
-					  timestamp->timezone/3600);
+					  (int) timestamp->fraction,
+					  (int) timestamp->timezone/3600);
 		break;
 	case GDA_VALUE_TYPE_GEOMETRIC_POINT:
 		point = gda_value_get_geometric_point (value);
@@ -1786,6 +2067,9 @@ gda_value_compare (const GdaValue *value1, const GdaValue *value2)
 	case GDA_VALUE_TYPE_BIGINT :
 		retval = (gint) value1->value.v_bigint - value2->value.v_bigint;
 		break;
+        case GDA_VALUE_TYPE_BIGUINT :
+                retval = (gint) value1->value.v_biguint - value2->value.v_biguint;
+                break;
 	case GDA_VALUE_TYPE_BINARY :
 		/* FIXME */
 		retval = 0;
@@ -1842,6 +2126,9 @@ gda_value_compare (const GdaValue *value1, const GdaValue *value2)
 	case GDA_VALUE_TYPE_SMALLINT :
 		retval = value1->value.v_smallint - value2->value.v_smallint;
 		break;
+        case GDA_VALUE_TYPE_SMALLUINT :
+                retval = value1->value.v_smalluint - value2->value.v_smalluint;
+                break;
 	case GDA_VALUE_TYPE_STRING :
 		retval = strcmp (value1->value.v_string, value2->value.v_string);
 		break;
@@ -1857,9 +2144,15 @@ gda_value_compare (const GdaValue *value1, const GdaValue *value2)
 	case GDA_VALUE_TYPE_TINYINT :
 		retval = value1->value.v_tinyint - value2->value.v_tinyint;
 		break;
+        case GDA_VALUE_TYPE_TINYUINT:
+                retval = value1->value.v_tinyuint - value2->value.v_tinyuint;
+                break;
 	case GDA_VALUE_TYPE_TYPE :
 		retval = value1->value.v_type == value2->value.v_type ? 0 : -1;
 		break;
+	case GDA_VALUE_TYPE_UINTEGER :
+                retval = value1->value.v_integer - value2->value.v_integer;
+                break;
 	default :
 		/* FIXME */
 		retval = -1;
@@ -1876,16 +2169,8 @@ gda_value_compare (const GdaValue *value1, const GdaValue *value2)
  * because of some localization with gda_value_stingify ().
  */
 static gchar *
-to_string (GdaValue *value)
+to_string (const GdaValue *value)
 {
-	const GdaTime *gdatime;
-	const GdaDate *gdadate;
-	const GdaTimestamp *timestamp;
-	const GdaGeometricPoint *point;
-	const GdaValueList *list;
-	const GdaNumeric *numeric;
-	GList *l;
-	GString *str = NULL;
 	gchar *retval = NULL;
 
 	g_return_val_if_fail (value != NULL, NULL);
@@ -1915,7 +2200,7 @@ to_string (GdaValue *value)
  * needed anymore, you should free it.
  */
 xmlNodePtr
-gda_value_to_xml (GdaValue *value)
+gda_value_to_xml (const GdaValue *value)
 {
 	gchar *valstr;
 	xmlNodePtr retval;
