@@ -29,6 +29,7 @@
 struct _GdaXmlDatabasePrivate {
 	gchar *uri;
 	gchar *name;
+	gchar *version;
 	GHashTable *tables;
 	GHashTable *views;
 	GHashTable *queries;
@@ -55,6 +56,7 @@ struct _GdaXmlDatabasePrivate {
 #define PROPERTY_SCALE       "scale"
 #define PROPERTY_SIZE        "size"
 #define PROPERTY_UNIQUE_KEY  "unique"
+#define PROPERTY_VERSION     "version"
 
 static void gda_xml_database_class_init (GdaXmlDatabaseClass *klass);
 static void gda_xml_database_init       (GdaXmlDatabase *xmldb, GdaXmlDatabaseClass *klass);
@@ -99,6 +101,20 @@ process_views_node (GdaXmlDatabase *xmldb, xmlNodePtr children)
 	g_return_if_fail (children != NULL);
 }
 
+/*
+ * Callbacks
+ */
+
+static void
+table_changed_cb (GdaDataModel *model, gpointer user_data)
+{
+	GdaXmlDatabase *xmldb = (GdaXmlDatabase *) user_data;
+
+	g_return_if_fail (GDA_IS_XML_DATABASE (xmldb));
+
+	gda_xml_database_changed (xmldb);
+}
+
 /*
  * GdaXmlDatabase class interface
  */
@@ -132,6 +148,7 @@ gda_xml_database_init (GdaXmlDatabase *xmldb, GdaXmlDatabaseClass *klass)
 	xmldb->priv = g_new0 (GdaXmlDatabasePrivate, 1);
 	xmldb->priv->uri = NULL;
 	xmldb->priv->name = NULL;
+	xmldb->priv->version = NULL;
 	xmldb->priv->tables = g_hash_table_new (g_str_hash, g_str_equal);
 	xmldb->priv->views = g_hash_table_new (g_str_hash, g_str_equal);
 	xmldb->priv->queries = g_hash_table_new (g_str_hash, g_str_equal);
@@ -141,6 +158,7 @@ static gboolean
 remove_table_hash (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (value), table_changed_cb, user_data);
 	g_object_unref (G_OBJECT (value));
 	return TRUE;
 }
@@ -158,7 +176,17 @@ gda_xml_database_finalize (GObject *object)
 		xmldb->priv->uri = NULL;
 	}
 
-	g_hash_table_foreach_remove (xmldb->priv->tables, remove_table_hash, NULL);
+	if (xmldb->priv->name) {
+		g_free (xmldb->priv->name);
+		xmldb->priv->name = NULL;
+	}
+
+	if (xmldb->priv->version) {
+		g_free (xmldb->priv->version);
+		xmldb->priv->version = NULL;
+	}
+
+	g_hash_table_foreach_remove (xmldb->priv->tables, remove_table_hash, xmldb);
 	g_hash_table_destroy (xmldb->priv->tables);
 	xmldb->priv->tables = NULL;
 
@@ -257,6 +285,7 @@ gda_xml_database_new_from_uri (const gchar *uri)
 	}
 
 	xmldb->priv->name = g_strdup (xmlGetProp (root, PROPERTY_NAME));
+	xmldb->priv->version = g_strdup  (xmlGetProp (root, PROPERTY_VERSION));
 	node = root->xmlChildrenNode;
 	while (node) {
 		xmlNodePtr children;
@@ -301,6 +330,10 @@ gda_xml_database_get_name (GdaXmlDatabase *xmldb)
 
 /**
  * gda_xml_database_set_name
+ * @xmldb: XML database.
+ * @name: new name for the database.
+ *
+ * Set the name of the given XML database object.
  */
 void
 gda_xml_database_set_name (GdaXmlDatabase *xmldb, const gchar *name)
@@ -314,6 +347,42 @@ gda_xml_database_set_name (GdaXmlDatabase *xmldb, const gchar *name)
 	gda_xml_database_changed (xmldb);
 }
 
+/**
+ * gda_xml_database_get_version
+ * @xmldb: XML database.
+ *
+ * Get the version of the given #GdaXmlDatabase object. This version is the
+ * one that was used for saving the XML file last time it was saved.
+ *
+ * Returns: the database version.
+ */
+const gchar *
+gda_xml_database_get_version (GdaXmlDatabase *xmldb)
+{
+	g_return_val_if_fail (GDA_IS_XML_DATABASE (xmldb), NULL);
+	return (const gchar *) xmldb->priv->version;
+}
+
+/**
+ * gda_xml_database_set_version
+ * @xmldb: XML database.
+ * @version: Version string.
+ *
+ * Set the version of the given XML database.
+ */
+void
+gda_xml_database_set_version (GdaXmlDatabase *xmldb, const gchar *version)
+{
+	g_return_if_fail (GDA_IS_XML_DATABASE (xmldb));
+	g_return_if_fail (version != NULL);
+
+	if (xmldb->priv->version)
+		g_free (xmldb->priv->version);
+	xmldb->priv->version = g_strdup (version);
+
+	gda_xml_database_changed (xmldb);
+}
+
 /**
  * gda_xml_database_get_uri
  * @xmldb: XML database.
@@ -388,6 +457,7 @@ gda_xml_database_save (GdaXmlDatabase *xmldb, const gchar *uri)
 
 	g_return_val_if_fail (GDA_IS_XML_DATABASE (xmldb), FALSE);
 
+	gda_xml_database_set_version (xmldb, VERSION);
 	xml = gda_xml_database_to_string (xmldb);
 	if (xml) {
 		result = gda_file_save (uri, xml, strlen (xml));
@@ -424,6 +494,8 @@ gda_xml_database_to_string (GdaXmlDatabase *xmldb)
 	/* create the top node */
 	doc = xmlNewDoc ("1.0");
 	root = xmlNewDocNode (doc, NULL, OBJECT_DATABASE, NULL);
+	xmlSetProp (root, PROPERTY_NAME, xmldb->priv->name);
+	xmlSetProp (root, PROPERTY_VERSION, VERSION);
 	xmlDocSetRootElement (doc, root);
 
 	/* add tables */
@@ -447,7 +519,7 @@ gda_xml_database_to_string (GdaXmlDatabase *xmldb)
 
 	gda_xml_database_free_table_list (list);
 
-	/* save to file */
+	/* save to memory */
 	xmlDocDumpMemory (doc, &xml, &size);
 	xmlFreeDoc (doc);
 	if (!xml) {
@@ -549,6 +621,7 @@ gda_xml_database_new_table (GdaXmlDatabase *xmldb, const gchar *name)
 	}
 
 	table = gda_table_new (name);
+	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
 	g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
 	gda_xml_database_changed (xmldb);
 
@@ -585,6 +658,7 @@ gda_xml_database_new_table_from_model (GdaXmlDatabase *xmldb,
 	}
 
 	table = gda_table_new_from_model (name, model, add_data);
+	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
 	if (GDA_IS_TABLE (table)) {
 		g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
 		gda_xml_database_changed (xmldb);
@@ -675,6 +749,7 @@ gda_xml_database_new_table_from_node (GdaXmlDatabase *xmldb, xmlNodePtr node)
 
 	/* add the table to the XML database object */
 	g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
+	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
 	gda_xml_database_changed (xmldb);
 
 	return table;
